pub struct KrakenSpotWebSocketClient { /* private fields */ }Expand description
WebSocket client for the Kraken Spot v2 streaming API.
Implementations
Sourceimpl KrakenSpotWebSocketClient
impl KrakenSpotWebSocketClient
Sourcepub fn new(
config: KrakenDataClientConfig,
cancellation_token: CancellationToken,
proxy_url: Option<String>,
) -> Self
pub fn new( config: KrakenDataClientConfig, cancellation_token: CancellationToken, proxy_url: Option<String>, ) -> Self
Creates a new client with the given configuration.
Sourcepub async fn connect(&mut self) -> Result<(), KrakenWsError>
pub async fn connect(&mut self) -> Result<(), KrakenWsError>
Connects to the WebSocket server.
Sourcepub async fn disconnect(&mut self) -> Result<(), KrakenWsError>
pub async fn disconnect(&mut self) -> Result<(), KrakenWsError>
Disconnects from the WebSocket server.
Sourcepub async fn close(&mut self) -> Result<(), KrakenWsError>
pub async fn close(&mut self) -> Result<(), KrakenWsError>
Closes the WebSocket connection.
Sourcepub async fn wait_until_active(
&self,
timeout_secs: f64,
) -> Result<(), KrakenWsError>
pub async fn wait_until_active( &self, timeout_secs: f64, ) -> Result<(), KrakenWsError>
Waits until the connection is active or timeout.
Sourcepub fn is_authenticated(&self) -> bool
pub fn is_authenticated(&self) -> bool
Returns true if the WebSocket is authenticated for private subscriptions.
Sourcepub async fn wait_until_authenticated(
&self,
timeout_secs: f64,
) -> Result<(), KrakenWsError>
pub async fn wait_until_authenticated( &self, timeout_secs: f64, ) -> Result<(), KrakenWsError>
Waits until the WebSocket is authenticated or the timeout elapses.
Returns an error on timeout or explicit auth failure.
Sourcepub async fn authenticate(&self) -> Result<(), KrakenWsError>
pub async fn authenticate(&self) -> Result<(), KrakenWsError>
Authenticates with the Kraken API to enable private subscriptions.
Sourcepub fn cancel_all_requests(&self)
pub fn cancel_all_requests(&self)
Cancels all pending requests.
Sourcepub fn cancellation_token(&self) -> &CancellationToken
pub fn cancellation_token(&self) -> &CancellationToken
Returns the cancellation token for this client.
Sourcepub async fn subscribe(
&self,
channel: KrakenWsChannel,
symbols: Vec<Ustr>,
depth: Option<u32>,
) -> Result<(), KrakenWsError>
pub async fn subscribe( &self, channel: KrakenWsChannel, symbols: Vec<Ustr>, depth: Option<u32>, ) -> Result<(), KrakenWsError>
Subscribes to a channel for the given symbols.
Sourcepub async fn unsubscribe(
&self,
channel: KrakenWsChannel,
symbols: Vec<Ustr>,
) -> Result<(), KrakenWsError>
pub async fn unsubscribe( &self, channel: KrakenWsChannel, symbols: Vec<Ustr>, ) -> Result<(), KrakenWsError>
Unsubscribes from a channel for the given symbols.
Sourcepub async fn send_ping(&self) -> Result<(), KrakenWsError>
pub async fn send_ping(&self) -> Result<(), KrakenWsError>
Sends a ping message to keep the connection alive.
Sourcepub fn is_connected(&self) -> bool
pub fn is_connected(&self) -> bool
Returns true if connected (not closed).
Sourcepub fn get_subscriptions(&self) -> Vec<String>
pub fn get_subscriptions(&self) -> Vec<String>
Returns all active subscriptions.
Sourcepub fn set_account_id(&self, account_id: AccountId)
pub fn set_account_id(&self, account_id: AccountId)
Sets the account ID for execution report parsing.
Sourcepub fn account_id(&self) -> Option<AccountId>
pub fn account_id(&self) -> Option<AccountId>
Returns the account ID if set.
Sourcepub fn cache_instrument(&self, instrument: InstrumentAny)
pub fn cache_instrument(&self, instrument: InstrumentAny)
Caches an instrument for execution report parsing.
Returns a shared reference to the account ID.
Sourcepub fn truncated_id_map(&self) -> &Arc<AtomicMap<String, ClientOrderId>> ⓘ
pub fn truncated_id_map(&self) -> &Arc<AtomicMap<String, ClientOrderId>> ⓘ
Returns a shared reference to the truncated ID map.
Sourcepub fn cache_client_order(
&self,
client_order_id: ClientOrderId,
_venue_order_id: Option<VenueOrderId>,
_instrument_id: InstrumentId,
_trader_id: TraderId,
_strategy_id: StrategyId,
)
pub fn cache_client_order( &self, client_order_id: ClientOrderId, _venue_order_id: Option<VenueOrderId>, _instrument_id: InstrumentId, _trader_id: TraderId, _strategy_id: StrategyId, )
Caches a client order for truncated ID resolution.
Sourcepub fn stream(
&mut self,
) -> Result<impl Stream<Item = KrakenSpotWsMessage> + use<>, KrakenWsError>
pub fn stream( &mut self, ) -> Result<impl Stream<Item = KrakenSpotWsMessage> + use<>, KrakenWsError>
Returns a stream of WebSocket messages.
Errors
Returns an error if:
- The stream receiver has already been taken
- Other clones of this client still hold references to the receiver
Sourcepub async fn subscribe_book(
&self,
instrument_id: InstrumentId,
depth: Option<u32>,
) -> Result<(), KrakenWsError>
pub async fn subscribe_book( &self, instrument_id: InstrumentId, depth: Option<u32>, ) -> Result<(), KrakenWsError>
Subscribes to order book updates for the given instrument.
Sourcepub async fn subscribe_quotes(
&self,
instrument_id: InstrumentId,
) -> Result<(), KrakenWsError>
pub async fn subscribe_quotes( &self, instrument_id: InstrumentId, ) -> Result<(), KrakenWsError>
Subscribes to quote updates for the given instrument.
Uses the Ticker channel with event_trigger: "bbo" for updates only on
best bid/offer changes.
Sourcepub async fn subscribe_trades(
&self,
instrument_id: InstrumentId,
) -> Result<(), KrakenWsError>
pub async fn subscribe_trades( &self, instrument_id: InstrumentId, ) -> Result<(), KrakenWsError>
Subscribes to trade updates for the given instrument.
Sourcepub async fn subscribe_bars(
&self,
bar_type: BarType,
) -> Result<(), KrakenWsError>
pub async fn subscribe_bars( &self, bar_type: BarType, ) -> Result<(), KrakenWsError>
Subscribes to bar/OHLC updates for the given bar type.
Errors
Returns an error if the bar aggregation is not supported by Kraken.
Sourcepub async fn subscribe_executions(
&self,
snap_orders: bool,
snap_trades: bool,
) -> Result<(), KrakenWsError>
pub async fn subscribe_executions( &self, snap_orders: bool, snap_trades: bool, ) -> Result<(), KrakenWsError>
Subscribes to execution updates (order and fill events).
Requires authentication - call authenticate() first.
Sourcepub async fn unsubscribe_book(
&self,
instrument_id: InstrumentId,
) -> Result<(), KrakenWsError>
pub async fn unsubscribe_book( &self, instrument_id: InstrumentId, ) -> Result<(), KrakenWsError>
Unsubscribes from order book updates for the given instrument.
Sourcepub async fn unsubscribe_quotes(
&self,
instrument_id: InstrumentId,
) -> Result<(), KrakenWsError>
pub async fn unsubscribe_quotes( &self, instrument_id: InstrumentId, ) -> Result<(), KrakenWsError>
Unsubscribes from quote updates for the given instrument.
Sourcepub async fn unsubscribe_trades(
&self,
instrument_id: InstrumentId,
) -> Result<(), KrakenWsError>
pub async fn unsubscribe_trades( &self, instrument_id: InstrumentId, ) -> Result<(), KrakenWsError>
Unsubscribes from trade updates for the given instrument.
Sourcepub async fn unsubscribe_bars(
&self,
bar_type: BarType,
) -> Result<(), KrakenWsError>
pub async fn unsubscribe_bars( &self, bar_type: BarType, ) -> Result<(), KrakenWsError>
Unsubscribes from bar/OHLC updates for the given bar type.
Errors
Returns an error if the bar aggregation is not supported by Kraken.